@@ -79,7 +79,7 @@ struct sitmo_enable_if<false, T> { };
 template<typename T>
 struct has_generate_template
 {
-  typedef char (&Two)[2];;
+  typedef char (&Two)[2];
   template<typename F, void (F::*)(int *, int *)> struct helper {};
   template<typename C> static char test(helper<C, &C::template generate<int*> >*);
   template<typename C> static Two test(...);
@@ -388,4 +388,4 @@ private:
 #undef MIXK
 #undef MIX2
 
-#endif
\ No newline at end of file
+#endif
